==> digikam_3.0.0~rc.orig.tar.bz2: digikam-3.0.0-rc/extra/libkipi/tests/kxmlhelloworld/plugin/kipiplugin_kxmlhelloworld.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=KXMLHelloWorld
Name[ca]=KXMLHelloWorld
Name[da]=KXMLHelloWorld
Name[el]=KXMLHelloWorld
Name[es]=KXMLHelloWorld
Name[et]=KXMLHelloWorld
Name[fi]=KXMLHelloWorld
Name[ga]=KXMLHelloWorld
Name[gl]=KXMLHelloWorld
Name[hu]=KXMLHelloWorld
Name[lt]=KXMLHelloWorld
Name[nb]=KXML Hallo_verden
Name[nl]=KXML-HelloWorld
Name[pl]=KXMLHelloWorld
Name[pt]=KXMLHelloWorld
Name[pt_BR]=Olá mundo KXML
Name[sk]=KXMLHelloWorld
Name[sr]=КДЕ‑ИксМЛ-здраво-свете
Name[sr@ijekavian]=КДЕ‑ИксМЛ-здраво-свете
Name[sr@ijekavianlatin]=KDE-XML-zdravo-svete
Name[sr@latin]=KDE-XML-zdravo-svete
Name[sv]=KXML Hello World
Name[uk]=KXMLHelloWorld
Name[x-test]=xxKXMLHelloWorldxx
Name[zh_CN]=KXMLHelloWorld
Name[zh_TW]=KXMLHelloWorld
Comment=A demo kipi tool using KDE XML-GUI technology
Comment[ca]=Una demostració de l'eina kipi que utilitza la tecnologia XML-GUI del KDE
Comment[da]=Et demo KIPI-værktøj der bruger KDE XML-GUI-teknologi
Comment[el]=Ένα εργαλείο επίδειξης kipi με χρήση τεχνολογίας KDE XML-GUI
Comment[es]=Una herramienta kipi de demostración que usa la tecnología XML-GUI de KDE
Comment[et]=KIPI demotööriist, mis kasutab KDE XML-GUI tehnoloogiat
Comment[fi]=KDE:n XML-GUI-teknologiaa käyttävä KIPI-työkaludemo
Comment[gl]=Unha ferramenta de demostración de kipi que emprega a tecnoloxía XML-GUI de KDE
Comment[hu]=Egy KDE XML-GUI technológiát használó demó kipi eszköz
Comment[lt]=Kipi demo įrankis naudojantis KDE XML-GUI technologiją
Comment[nb]=Et kipi demo-verktøy som bruker KDEs XML-GUI-teknologi
Comment[nl]=Een demo kipi-hulpmiddel die KDE XML-GUI technologie gebruikt
Comment[pl]=Demonstracyjne narzędzie kipi używające technologi KDE XML-GUI
Comment[pt]=Uma ferramenta de demonstração do KIPI que usa a tecnologia XML-GUI do KDE
Comment[pt_BR]=Uma ferramenta do KIPI que usa a tecnologia KDE XML-GUI
Comment[sk]=Ukážkový kipi nástroj používajúci technológiu KDE XML-GUI
Comment[sr]=Демонстрациона КИПИ алатка на технологији КДЕ‑овог ИксМЛ ГУИ‑ја
Comment[sr@ijekavian]=Демонстрациона КИПИ алатка на технологији КДЕ‑овог ИксМЛ ГУИ‑ја
Comment[sr@ijekavianlatin]=Demonstraciona KIPI alatka na tehnologiji KDE‑ovog XML GUI‑ja
Comment[sr@latin]=Demonstraciona KIPI alatka na tehnologiji KDE‑ovog XML GUI‑ja
Comment[sv]=Ett KIPI-verktyg för demonstration av KDE:s XML-GUI-teknologi
Comment[uk]=Тестовий інструмент KIPI щодо використання технології XML-GUI KDE
Comment[x-test]=xxA demo kipi tool using KDE XML-GUI technologyxx
Comment[zh_CN]=使用 KDE XML-GUI 技术的 kipi 演示程序
Comment[zh_TW]=示範用的 kipi 工具，使用 KDE XML-GUI 技術
Type=Service
Icon=script-error
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kxmlhelloworld
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-ReqFeatures=
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
X-KIPI-PluginCategories=Image,Tools,Export,Import

==> digikam-3.1.0.tar.bz2: digikam-3.1.0/extra/libkipi/tests/kxmlhelloworld/plugin/kipiplugin_kxmlhelloworld.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=KXMLHelloWorld
Name=KXMLHelloWorld
Name[ca]=KXMLHelloWorld
Name[ca@valencia]=KXMLHelloWorld
Name[cs]=KXMLHelloWorld
Name[da]=KXMLHelloWorld
Name[de]=KXMLHelloWorld
Name[el]=KXMLHelloWorld
Name[es]=KXMLHelloWorld
Name[et]=KXMLHelloWorld
Name[fi]=KXMLHelloWorld
Name[fr]=KXMLHelloWorld
Name[ga]=KXMLHelloWorld
Name[gl]=KXMLHelloWorld
Name[hu]=KXMLHelloWorld
Name[ia]=KXMLSaluteMundo
Name[kk]=KXMLHelloWorld
Name[ko]=KXMLHelloWorld
Name[lt]=KXMLHelloWorld
Name[mr]=KXMLहेल्लोवर्ल्ड
Name[nb]=KXML Hallo_verden
Name[nl]=KXML-HelloWorld
Name[pl]=KXMLHelloWorld
Name[pt]=KXMLHelloWorld
Name[pt_BR]=Olá mundo KXML
Name[ro]=KXMLHelloWorld
Name[ru]=KXMLHelloWorld
Name[sk]=KXMLHelloWorld
Name[sr]=КДЕ‑ИксМЛ-здраво-свете
Name[sr@ijekavian]=КДЕ‑ИксМЛ-здраво-свете
Name[sr@ijekavianlatin]=KDE-XML-zdravo-svete
Name[sr@latin]=KDE-XML-zdravo-svete
Name[sv]=KXML Hello World
Name[uk]=KXMLHelloWorld
Name[x-test]=xxKXMLHelloWorldxx
Name[zh_CN]=KXMLHelloWorld
Name[zh_TW]=KXMLHelloWorld
Comment=A demo kipi tool using KDE XML-GUI technology
Comment[ca]=Una demostració de l'eina kipi que utilitza la tecnologia XML-GUI del KDE
Comment[ca@valencia]=Una demostració de l'eina kipi que utilitza la tecnologia XML-GUI del KDE
Comment[da]=Et demo KIPI-værktøj der bruger KDE XML-GUI-teknologi
Comment[de]=Demo eines KIPI-Moduls. das die KDE-Technologie XML-GUI verwendet
Comment[el]=Ένα εργαλείο επίδειξης kipi με χρήση τεχνολογίας KDE XML-GUI
Comment[es]=Una herramienta kipi de demostración que usa la tecnología XML-GUI de KDE
Comment[et]=KIPI demotööriist, mis kasutab KDE XML-GUI tehnoloogiat
Comment[fi]=KDE:n XML-GUI-teknologiaa käyttävä KIPI-työkaludemo
Comment[fr]=Un outil KIPI de démonstration utilisante la technologie d'interface dgraphique XML de KDE
Comment[gl]=Unha ferramenta de demostración de kipi que emprega a tecnoloxía XML-GUI de KDE
Comment[hu]=Egy KDE XML-GUI technológiát használó demó kipi eszköz
Comment[ia]=Un instrumento de demonstration de kipi que usa technologia KDE XML-GUI
Comment[kk]=KDE XML-GUI технологиясын қолданатың демо kipi құралы
Comment[ko]=KDE XML-GUI를 사용하는 KIPI 도구 데모
Comment[lt]=Kipi demo įrankis naudojantis KDE XML-GUI technologiją
Comment[mr]=केडीई XML-GUI तंत्रज्ञान वापरणारे एक डेमो किपि साधन
Comment[nb]=Et kipi demo-verktøy som bruker KDEs XML-GUI-teknologi
Comment[nl]=Een demo kipi-hulpmiddel die KDE XML-GUI technologie gebruikt
Comment[pl]=Demonstracyjne narzędzie kipi używające technologi KDE XML-GUI
Comment[pt]=Uma ferramenta de demonstração do KIPI que usa a tecnologia XML-GUI do KDE
Comment[pt_BR]=Uma ferramenta do KIPI que usa a tecnologia KDE XML-GUI
Comment[ro]=Unealtă kipi demonstrativă folosind tehnologia KDE XML-GUI
Comment[ru]=Тестовый инструмент KIPI по использованию технологии XML-GUI KDE
Comment[sk]=Ukážkový kipi nástroj používajúci technológiu KDE XML-GUI
Comment[sr]=Демонстрациона КИПИ алатка на технологији КДЕ‑овог ИксМЛ ГУИ‑ја
Comment[sr@ijekavian]=Демонстрациона КИПИ алатка на технологији КДЕ‑овог ИксМЛ ГУИ‑ја
Comment[sr@ijekavianlatin]=Demonstraciona KIPI alatka na tehnologiji KDE‑ovog XML GUI‑ja
Comment[sr@latin]=Demonstraciona KIPI alatka na tehnologiji KDE‑ovog XML GUI‑ja
Comment[sv]=Ett KIPI-verktyg för demonstration av KDE:s XML-GUI-teknologi
Comment[uk]=Тестовий інструмент KIPI щодо використання технології XML-GUI KDE
Comment[x-test]=xxA demo kipi tool using KDE XML-GUI technologyxx
Comment[zh_CN]=使用 KDE XML-GUI 技术的 kipi 演示程序
Comment[zh_TW]=示範用的 kipi 工具，使用 KDE XML-GUI 技術
Type=Service
Icon=script-error
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kxmlhelloworld
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-ReqFeatures=
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
X-KIPI-PluginCategories=Image,Tools,Export,Import
